==> zio-aws-ec2_2.13-5.17.123.1-sources.jar: zio/aws/ec2/model/LocalGatewayVirtualInterface.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{Integer, LocalGatewayVirtualInterfaceId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class LocalGatewayVirtualInterface(
    localGatewayVirtualInterfaceId: Option[LocalGatewayVirtualInterfaceId] =
      None,
    localGatewayId: Option[String] = None,
    vlan: Option[Integer] = None,
    localAddress: Option[String] = None,
    peerAddress: Option[String] = None,
    localBgpAsn: Option[Integer] = None,
    peerBgpAsn: Option[Integer] = None,
    ownerId: Option[String] = None,
    tags: Option[Iterable[zio.aws.ec2.model.Tag]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.LocalGatewayVirtualInterface = {
    import LocalGatewayVirtualInterface.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.LocalGatewayVirtualInterface
      .builder()
      .optionallyWith(
        localGatewayVirtualInterfaceId.map(value =>
          LocalGatewayVirtualInterfaceId.unwrap(value): java.lang.String
        )
      )(_.localGatewayVirtualInterfaceId)
      .optionallyWith(localGatewayId.map(value => value: java.lang.String))(
        _.localGatewayId
      )
      .optionallyWith(
        vlan.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.vlan)
      .optionallyWith(localAddress.map(value => value: java.lang.String))(
        _.localAddress
      )
      .optionallyWith(peerAddress.map(value => value: java.lang.String))(
        _.peerAddress
      )
      .optionallyWith(
        localBgpAsn.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.localBgpAsn)
      .optionallyWith(
        peerBgpAsn.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.peerBgpAsn)
      .optionallyWith(ownerId.map(value => value: java.lang.String))(_.ownerId)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.LocalGatewayVirtualInterface.ReadOnly =
    zio.aws.ec2.model.LocalGatewayVirtualInterface.wrap(buildAwsValue())
}
object LocalGatewayVirtualInterface {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.LocalGatewayVirtualInterface
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.LocalGatewayVirtualInterface =
      zio.aws.ec2.model.LocalGatewayVirtualInterface(
        localGatewayVirtualInterfaceId.map(value => value),
        localGatewayId.map(value => value),
        vlan.map(value => value),
        localAddress.map(value => value),
        peerAddress.map(value => value),
        localBgpAsn.map(value => value),
        peerBgpAsn.map(value => value),
        ownerId.map(value => value),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def localGatewayVirtualInterfaceId: Option[LocalGatewayVirtualInterfaceId]
    def localGatewayId: Option[String]
    def vlan: Option[Integer]
    def localAddress: Option[String]
    def peerAddress: Option[String]
    def localBgpAsn: Option[Integer]
    def peerBgpAsn: Option[Integer]
    def ownerId: Option[String]
    def tags: Option[List[zio.aws.ec2.model.Tag.ReadOnly]]
    def getLocalGatewayVirtualInterfaceId
        : ZIO[Any, AwsError, LocalGatewayVirtualInterfaceId] =
      AwsError.unwrapOptionField(
        "localGatewayVirtualInterfaceId",
        localGatewayVirtualInterfaceId
      )
    def getLocalGatewayId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("localGatewayId", localGatewayId)
    def getVlan: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("vlan", vlan)
    def getLocalAddress: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("localAddress", localAddress)
    def getPeerAddress: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("peerAddress", peerAddress)
    def getLocalBgpAsn: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("localBgpAsn", localBgpAsn)
    def getPeerBgpAsn: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("peerBgpAsn", peerBgpAsn)
    def getOwnerId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("ownerId", ownerId)
    def getTags: ZIO[Any, AwsError, List[zio.aws.ec2.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.LocalGatewayVirtualInterface
  ) extends zio.aws.ec2.model.LocalGatewayVirtualInterface.ReadOnly {
    override val localGatewayVirtualInterfaceId
        : Option[LocalGatewayVirtualInterfaceId] = scala
      .Option(impl.localGatewayVirtualInterfaceId())
      .map(value =>
        zio.aws.ec2.model.primitives.LocalGatewayVirtualInterfaceId(value)
      )
    override val localGatewayId: Option[String] =
      scala.Option(impl.localGatewayId()).map(value => value: String)
    override val vlan: Option[Integer] = scala
      .Option(impl.vlan())
      .map(value => zio.aws.ec2.model.primitives.Integer(value))
    override val localAddress: Option[String] =
      scala.Option(impl.localAddress()).map(value => value: String)
    override val peerAddress: Option[String] =
      scala.Option(impl.peerAddress()).map(value => value: String)
    override val localBgpAsn: Option[Integer] = scala
      .Option(impl.localBgpAsn())
      .map(value => zio.aws.ec2.model.primitives.Integer(value))
    override val peerBgpAsn: Option[Integer] = scala
      .Option(impl.peerBgpAsn())
      .map(value => zio.aws.ec2.model.primitives.Integer(value))
    override val ownerId: Option[String] =
      scala.Option(impl.ownerId()).map(value => value: String)
    override val tags: Option[List[zio.aws.ec2.model.Tag.ReadOnly]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.Tag.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.LocalGatewayVirtualInterface
  ): zio.aws.ec2.model.LocalGatewayVirtualInterface.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.155.1-sources.jar: zio/aws/ec2/model/LocalGatewayVirtualInterface.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{Integer, LocalGatewayVirtualInterfaceId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class LocalGatewayVirtualInterface(
    localGatewayVirtualInterfaceId: Option[LocalGatewayVirtualInterfaceId] =
      None,
    localGatewayId: Option[String] = None,
    vlan: Option[Integer] = None,
    localAddress: Option[String] = None,
    peerAddress: Option[String] = None,
    localBgpAsn: Option[Integer] = None,
    peerBgpAsn: Option[Integer] = None,
    ownerId: Option[String] = None,
    tags: Option[Iterable[zio.aws.ec2.model.Tag]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.LocalGatewayVirtualInterface = {
    import LocalGatewayVirtualInterface.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.LocalGatewayVirtualInterface
      .builder()
      .optionallyWith(
        localGatewayVirtualInterfaceId.map(value =>
          LocalGatewayVirtualInterfaceId.unwrap(value): java.lang.String
        )
      )(_.localGatewayVirtualInterfaceId)
      .optionallyWith(localGatewayId.map(value => value: java.lang.String))(
        _.localGatewayId
      )
      .optionallyWith(vlan.map(value => value: java.lang.Integer))(_.vlan)
      .optionallyWith(localAddress.map(value => value: java.lang.String))(
        _.localAddress
      )
      .optionallyWith(peerAddress.map(value => value: java.lang.String))(
        _.peerAddress
      )
      .optionallyWith(localBgpAsn.map(value => value: java.lang.Integer))(
        _.localBgpAsn
      )
      .optionallyWith(peerBgpAsn.map(value => value: java.lang.Integer))(
        _.peerBgpAsn
      )
      .optionallyWith(ownerId.map(value => value: java.lang.String))(_.ownerId)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.LocalGatewayVirtualInterface.ReadOnly =
    zio.aws.ec2.model.LocalGatewayVirtualInterface.wrap(buildAwsValue())
}
object LocalGatewayVirtualInterface {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.LocalGatewayVirtualInterface
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.LocalGatewayVirtualInterface =
      zio.aws.ec2.model.LocalGatewayVirtualInterface(
        localGatewayVirtualInterfaceId.map(value => value),
        localGatewayId.map(value => value),
        vlan.map(value => value),
        localAddress.map(value => value),
        peerAddress.map(value => value),
        localBgpAsn.map(value => value),
        peerBgpAsn.map(value => value),
        ownerId.map(value => value),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def localGatewayVirtualInterfaceId: Option[LocalGatewayVirtualInterfaceId]
    def localGatewayId: Option[String]
    def vlan: Option[Integer]
    def localAddress: Option[String]
    def peerAddress: Option[String]
    def localBgpAsn: Option[Integer]
    def peerBgpAsn: Option[Integer]
    def ownerId: Option[String]
    def tags: Option[List[zio.aws.ec2.model.Tag.ReadOnly]]
    def getLocalGatewayVirtualInterfaceId
        : ZIO[Any, AwsError, LocalGatewayVirtualInterfaceId] =
      AwsError.unwrapOptionField(
        "localGatewayVirtualInterfaceId",
        localGatewayVirtualInterfaceId
      )
    def getLocalGatewayId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("localGatewayId", localGatewayId)
    def getVlan: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("vlan", vlan)
    def getLocalAddress: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("localAddress", localAddress)
    def getPeerAddress: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("peerAddress", peerAddress)
    def getLocalBgpAsn: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("localBgpAsn", localBgpAsn)
    def getPeerBgpAsn: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("peerBgpAsn", peerBgpAsn)
    def getOwnerId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("ownerId", ownerId)
    def getTags: ZIO[Any, AwsError, List[zio.aws.ec2.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.LocalGatewayVirtualInterface
  ) extends zio.aws.ec2.model.LocalGatewayVirtualInterface.ReadOnly {
    override val localGatewayVirtualInterfaceId
        : Option[LocalGatewayVirtualInterfaceId] = scala
      .Option(impl.localGatewayVirtualInterfaceId())
      .map(value =>
        zio.aws.ec2.model.primitives.LocalGatewayVirtualInterfaceId(value)
      )
    override val localGatewayId: Option[String] =
      scala.Option(impl.localGatewayId()).map(value => value: String)
    override val vlan: Option[Integer] =
      scala.Option(impl.vlan()).map(value => value: Integer)
    override val localAddress: Option[String] =
      scala.Option(impl.localAddress()).map(value => value: String)
    override val peerAddress: Option[String] =
      scala.Option(impl.peerAddress()).map(value => value: String)
    override val localBgpAsn: Option[Integer] =
      scala.Option(impl.localBgpAsn()).map(value => value: Integer)
    override val peerBgpAsn: Option[Integer] =
      scala.Option(impl.peerBgpAsn()).map(value => value: Integer)
    override val ownerId: Option[String] =
      scala.Option(impl.ownerId()).map(value => value: String)
    override val tags: Option[List[zio.aws.ec2.model.Tag.ReadOnly]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.Tag.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.LocalGatewayVirtualInterface
  ): zio.aws.ec2.model.LocalGatewayVirtualInterface.ReadOnly = new Wrapper(impl)
}
